@@ -5,9 +5,10 @@ sub parsectcp {
     &status("CTCP $type $dest request from $nick");
     if ($type =~ /^version/i) {
 	ctcpreply($nick, "VERSION", $version);
-    } elsif ($type =~ /^ping\s+([0-9]*)\s+([0-9]*)/i) {
+    } elsif ($type =~ /^(echo|ping) ?(.*)/i) { 
+	# thanks to hcf! bugs on bugs.
 	# thanks to behe (ericw@ix.netcom.com)
-	ctcpreply($nick, "PING $1 $2");
+	ctcpreply($nick, uc($1)." $2");
     } elsif ($type =~ /^DCC /) {
 	&status("DCC attempt from $who (not supported, ignored)");
     }
